referrerpolicy=no-referrer-when-downgrade

GenericTransaction

Struct GenericTransaction 

pub struct GenericTransaction {
Show 16 fields pub access_list: Option<AccessList>, pub authorization_list: Vec<AuthorizationListEntry>, pub blob_versioned_hashes: Vec<H256>, pub blobs: Vec<Bytes>, pub chain_id: Option<U256>, pub from: Option<Address>, pub gas: Option<U256>, pub gas_price: Option<U256>, pub input: InputOrData, pub max_fee_per_blob_gas: Option<U256>, pub max_fee_per_gas: Option<U256>, pub max_priority_fee_per_gas: Option<U256>, pub nonce: Option<U256>, pub to: Option<Address>, pub type: Option<Byte>, pub value: Option<U256>,
}
Transaction object generic to all types

Fields

access_list: Option<AccessList>

accessList EIP-2930 access list

authorization_list: Vec<AuthorizationListEntry>

authorizationList List of account code authorizations (EIP-7702)

blob_versioned_hashes: Vec<H256>

blobVersionedHashes List of versioned blob hashes associated with the transaction’s EIP-4844 data blobs.

blobs: Vec<Bytes>

blobs Raw blob data.

chain_id: Option<U256>

chainId Chain ID that this transaction is valid on.

from: Option<Address>

from address

gas: Option<U256>

gas limit

gas_price: Option<U256>

gas price The gas price willing to be paid by the sender in wei

input: InputOrData

input data

max_fee_per_blob_gas: Option<U256>

max fee per blob gas The maximum total fee per gas the sender is willing to pay for blob gas in wei

max_fee_per_gas: Option<U256>

max fee per gas The maximum total fee per gas the sender is willing to pay (includes the network / base fee and miner / priority fee) in wei

max_priority_fee_per_gas: Option<U256>

max priority fee per gas Maximum fee per gas the sender is willing to pay to miners in wei

nonce: Option<U256>

nonce

to: Option<Address>

to address

type: Option<Byte>

type

value: Option<U256>

value

Implementations

Source

impl GenericTransaction

pub fn from_signed( tx: TransactionSigned, base_gas_price: U256, from: Option<H160>, ) -> Self

Create a new GenericTransaction from a signed transaction.

pub fn has_simple_transfer_fields(&self) -> bool

Returns true when the transaction’s payload fields look like those of a simple value transfer: empty calldata, no access list, no EIP-7702 authorization list, no EIP-4844 blob payload, and no blob gas fee. The destination address is validated separately by the caller.

pub fn effective_gas_price(&self, base_gas_price: U256) -> Option<U256>

The gas price that is actually paid (including priority fee).

pub fn from_unsigned( tx: TransactionUnsigned, base_gas_price: U256, from: Option<H160>, ) -> Self

Create a new GenericTransaction from a unsigned transaction.

pub fn try_into_unsigned(self) -> Result<TransactionUnsigned, ()>

Convert to a TransactionUnsigned.

Source

impl GenericTransaction

pub fn into_call<T>( self, mode: CreateCallMode, ) -> Result<CallInfo<T>, InvalidTransaction>

Decode tx into a dispatchable call.